@@ -47,11 +47,11 @@ sub import {
 }
 
 
-our $VERSION = '0.0173';    # TRIAL VERSION
+our $VERSION = '0.0184';    # TRIAL VERSION
 
 1;
 
-# ABSTRACT: Perl Evo design pattern
+# ABSTRACT: Evo - the next generation component-oriented development framework
 
 __END__
 
@@ -61,11 +61,11 @@ __END__
 
 =head1 NAME
 
-Evo - Perl Evo design pattern
+Evo - Evo - the next generation component-oriented development framework
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 DESCRIPTION
 
@@ -75,60 +75,71 @@ It provides rewritten and postmodern features like
 =over
 
 =item *
-Rewritten sexy L<Evo::Exporter>
+Rewritten sexy L<Evo::Export>
 
 =item *
 Post modern component oriented programming L<Evo::Comp> instead of OO
 
 =item *
-Fast Event-Loop L<Evo::Loop> with unique feature zones (Not ready)
+(no docs yet) Fast Event-Loop L<Evo::Loop> with unique feature zones (Not ready)
 
 =item *
-Fast non recursive L<Evo::Promises>, 100% Promises/Spec A compatible
+(no docs yet) Fast non recursive L<Evo::Promises>, 100% Promises/Spec A compatible
 
 =item *
-Interesting L<Evo::Realm> design pattern, which is as handy as "Singleton" but without Sintleton's flaws.
-It makes real thing that are considered impossible in other languages. For example, testing EventLoop timers without patching, separating flows for one loop and so on.
-(ready but experimental and not documented)
+Interesting L<Evo::Realm> design pattern, which is as handy as "Singleton" but without Sintleton's flaws. Testable and mockable alternative of the global class
 
 =item *
 Exception handling in pure perl: L<Evo::Eval>, "try catch" alternative. Like C<Try::Tiny>, but without it's bugs and much faster
 
+=item *
+L<Evo::Ee> - a component role that gives your component "EventEmitter" abilities
+
 =back
 
+=head1 SYNOPSYS
+
+  # enables strict, warnings, utf8, :5.22, signatured, postderef
+  use Evo;
+
 =head1 IMPORTING
 
-Calls loads L<Evo::Eval> and calls it's C<import> method, emulating C<caller>.
+Load Module and call it's C<import> method, emulating C<caller>. 
 
   use Evo 'Evo::SomeComp';
   use Evo 'Evo::SomeComp(function)';
   use Evo 'Evo::SomeComp(function,otherfunc)';
   use Evo 'Evo::SomeComp function1 function2';
 
+Used to make package header shorter
+
+  use Evo '-Eval *; My::App';
+
 =head2 SHORTCUTS
 
   : => . (append to current)
   :: => .. (append to parent)
   - => Evo (append to Evo)
 
-Import C<Evo::SomeComp> namespace
+=head2 shortcuts
 
-  use Evo '-SomeComp';
+Shortcuts are used to make life easily during code refactoring (and you module shorter) in L<Evo::Export> and L<Evo::Comp/"with">
 
-Import C<My::Ns::Foo::Rel>:
+C<-> is replaced by C<Evo>
 
-  package My::Ns::Foo;
-  use Evo ':Bar';
+  use Evo '-Promises promise'; # "Evo::Promises promise"
 
-Import C<My::Ns::Bar>:
+C<:> and C<::> make sense in the package and depends on the package name where is used
 
-  package My::Ns::Foo;
-  use Evo '::Bar';
+C<:> means relative to the current module as a child
 
-You can split import by C<;>
+  package My::App;
+  use Evo ':Bar'; # My::App::Bar
 
-  package My::Ns::Foo;
-  use Evo ':Bar bar1; :Baz baz1; Other::Foo foo1';
+C<::> means as sibling (child of the parent of the current module)
+
+  package My::App;
+  use Evo '::Bar'; # My::Bar
 
 =head1 IMPORTS
 
@@ -138,11 +149,11 @@ With or without options, C<use Evo> loads L<Evo::Default>:
 
   use strict;
   use warnings;
-  use feature ':5.20';
+  use feature ':5.22';
+  use experimental 'signatures';
+  use feature 'postderef';
 
-=head2 -Modern
-
-Enable cool experimental features from L<Evo::Modern>
+I make some test and decided that using 5.22 and experimental features brings many benefits and worth it. This list will be expanded in the future, I hope
 
 =head2 -Loaded
 
@@ -163,7 +174,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
