@@ -9,8 +9,7 @@ my $GEN = {map { ($_, *{"gen_$_"}{CODE}) } qw(gs gsch gs_value gsch_value gs_cod
 
 sub GEN : Export {$GEN}
 
-sub gen_new {
-  my ($class, $opts) = @_;
+sub gen_new($class, $opts) {
 
   sub {
     my %attrs = @_;
@@ -31,8 +30,7 @@ sub gen_new {
 }
 
 
-sub gen_gs {
-  my ($name) = @_;
+sub gen_gs($name) {
   sub {
     return $_[0]->{$name} if @_ == 1;
     $_[0]->{$name} = $_[1];
@@ -40,8 +38,7 @@ sub gen_gs {
   };
 }
 
-sub gen_gs_value {
-  my ($name, $value) = @_;
+sub gen_gs_value($name, $value) {
   sub {
     return exists $_[0]->{$name} ? $_[0]->{$name} : $value if @_ == 1;
     $_[0]->{$name} = $_[1];
@@ -49,8 +46,7 @@ sub gen_gs_value {
   };
 }
 
-sub gen_gs_code {
-  my ($name, $fn) = @_;
+sub gen_gs_code($name, $fn) {
   sub {
     return exists $_[0]->{$name} ? $_[0]->{$name} : $fn->($_[0]) if @_ == 1;
     $_[0]->{$name} = $_[1];
@@ -59,8 +55,7 @@ sub gen_gs_code {
 }
 
 
-sub gen_gsch {
-  my ($name, $ch) = @_;
+sub gen_gsch($name, $ch) {
   sub {
     return $_[0]->{$name} if @_ == 1;
     my ($ok, $msg) = $ch->($_[1]);
@@ -70,8 +65,7 @@ sub gen_gsch {
   };
 }
 
-sub gen_gsch_value {
-  my ($name, $ch, $value) = @_;
+sub gen_gsch_value($name, $ch, $value) {
   sub {
     return exists $_[0]->{$name} ? $_[0]->{$name} : $value if @_ == 1;
     my ($ok, $msg) = $ch->($_[1]);
@@ -81,8 +75,7 @@ sub gen_gsch_value {
   };
 }
 
-sub gen_gsch_code {
-  my ($name, $ch, $code) = @_;
+sub gen_gsch_code($name, $ch, $code) {
   sub {
     return exists $_[0]->{$name} ? $_[0]->{$name} : $code->($_[0]) if @_ == 1;
     my ($ok, $msg) = $ch->($_[1]);
@@ -106,7 +99,7 @@ Evo::Comp::Gen::Hash
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -114,7 +107,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
