@@ -15,13 +15,11 @@ sub data { shift->{data} }
 sub new { bless {data => {}, @_}, __PACKAGE__; }
 
 
-sub builder_options {
-  my ($self, $class) = @_;
+sub builder_options($self, $class) {
   $self->data->{$class}{bo} ||= {};
 }
 
-sub install_attr {
-  my ($self, $class, $name, @xopts) = @_;
+sub install_attr($self, $class, $name, @xopts) {
   my $data = $self->data->{$class} ||= {};
   croak qq{"$class" already has attribute "$name"} if $data->{attrs}{$name};
 
@@ -36,8 +34,7 @@ sub install_attr {
 }
 
 # ro just adds chet wrapper
-sub compile_attr {
-  my ($self, $name, %opts) = @_;
+sub compile_attr($self, $name, %opts) {
   my $gen = $self->{gen};
   my $lt  = exists $opts{lazy} && (ref $opts{lazy} ? 'CODE' : 'VALUE');
   my $ch  = $opts{check};
@@ -61,8 +58,7 @@ sub compile_attr {
   $res;
 }
 
-sub update_builder_options {
-  my ($self, $class) = @_;
+sub update_builder_options($self, $class) {
   my $bo = $self->builder_options($class);
 
   # !!!reset by ref
@@ -77,15 +73,12 @@ sub update_builder_options {
   }
 }
 
-sub compile_builder {
-  my ($self, $class) = @_;
+sub compile_builder($self, $class) {
   $self->update_builder_options($class);
   return $self->{gen}{new}->($class, $self->builder_options($class));
 }
 
-sub parse_style {
-  my ($self, @attr) = @_;
-
+sub parse_style($self, @attr) {
   my %unknown = my %opts = (@attr % 2 ? (default => @attr) : @attr);
   delete $unknown{$_} for @KNOWN;
   croak "unknown options: " . join(',', sort keys %unknown) if keys %unknown;
@@ -98,8 +91,7 @@ sub parse_style {
   %opts;
 }
 
-sub install_roles {
-  my ($self, $comp, @roles) = @_;
+sub install_roles($self, $comp, @roles) {
   my $rex = $self->{rex};
   no strict 'refs';    ## no critic
   my @hslots;
@@ -121,13 +113,11 @@ sub install_roles {
 
 # ---- funcs ---
 
-sub gen_check_ro {
-  my $name = shift;
+sub gen_check_ro($name) {
   sub { croak qq#Attribute "$name" is readonly#; }
 }
 
-sub process_is {
-  my ($name, %res) = @_;
+sub process_is($name, %res) {
   my $is = delete($res{is}) || 'rw';
   croak qq#invalid "is": "$is"# unless $is eq 'ro' || $is eq 'rw';
 
@@ -135,8 +125,7 @@ sub process_is {
   return %res;
 }
 
-sub _scalar_or_code {
-  my ($opts, $what) = @_;
+sub _scalar_or_code($opts, $what) {
   croak qq#"$what" should be either a code reference or a scalar value#
     if ref $opts->{$what} && ref $opts->{$what} ne 'CODE';
 }
@@ -156,7 +145,7 @@ Evo::Comp::Meta
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -164,7 +153,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
