@@ -8,14 +8,12 @@ use Module::Load;
 sub data { shift->{data} }
 sub new { bless {data => {}}, __PACKAGE__ }
 
-sub init_slot {
-  my ($self, $src, $name, $val) = @_;
+sub init_slot($self, $src, $name, $val) {
   croak "$src already adds $name" if $self->data->{$src}{export}{$name};
   $self->data->{$src}{export}{$name} = $val;
 }
 
-sub add_methods {
-  my ($self, $role, @methods) = @_;
+sub add_methods($self, $role, @methods) {
   no strict 'refs';    ## no critic
   foreach my $m (@methods) {
     my $full = "${role}::$m";
@@ -24,13 +22,11 @@ sub add_methods {
   }
 }
 
-sub add_gen {
-  my ($self, $role, $name, $gen) = @_;
+sub add_gen($self, $role, $name, $gen) {
   $self->init_slot($role, $name, {type => 'gen', value => $gen});
 }
 
-sub request_gen {
-  my ($self, $role, $name, $comp) = @_;
+sub request_gen($self, $role, $name, $comp) {
   my $slot = $self->data->{$role}{export}{$name}
     or croak qq#"$role" doesn't provide method "$name"#;
 
@@ -39,29 +35,25 @@ sub request_gen {
   return $slot->{cache}{$comp} = $slot->{value}->($comp);
 }
 
-sub add_attr {
-  my ($self, $role, $name, @opts) = @_;
+sub add_attr($self, $role, $name, @opts) {
   Evo::Util::check_subname($name) || croak(qq{Attribute "$name" invalid});
   $self->init_slot($role, $name, {type => 'attr', value => \@opts});
 }
 
-sub _map {
-  my ($self, $type, $role) = @_;
+sub _map($self, $type, $role) {
   my $all = $self->data->{$role}{export};
   map { ($_, $all->{$_}->{value}) } grep { $all->{$_}->{type} eq $type } keys %$all;
 }
 
-sub methods {
-  my ($self, $role, $comp) = @_;
+sub methods($self, $role, $comp) {
   my %gens = $self->_map('gen', $role);
   my %gms = map { $_ => $gens{$_}->($comp) } keys %gens;
   (%gms, $self->_map('method', $role),);
 }
 
-sub attrs { shift->_map('attr', shift); }
+sub attrs($self, $role) { $self->_map('attr', $role); }
 
-sub hooks {
-  my ($self, $role, @hooks) = @_;
+sub hooks($self, $role, @hooks) {
 
   return $self->data->{$role}
     && $self->data->{$role}{hooks} ? ($self->data->{$role}{hooks}->@*) : ()
@@ -69,8 +61,7 @@ sub hooks {
   push @{($self->data->{$role}{hooks} ||= [])}, @hooks;
 }
 
-sub proxy {
-  my ($self, $dst, $src) = @_;
+sub proxy($self, $dst, $src) {
   load $src;
 
   my $data_src = $self->data->{$src} || {};
@@ -101,7 +92,7 @@ Evo::Comp::Role::Exporter
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -109,7 +100,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
