@@ -3,8 +3,7 @@ use Evo;
 use Evo::Export '*';
 use Carp 'croak';
 
-sub croak_bad_value : Export {
-  my ($value, $name, $msg) = @_;
+sub croak_bad_value($value, $name, $msg=undef) : Export {
   my $err = qq'Bad value "$value" for attribute "$name"';
   $err .= ": $msg" if $msg;
   croak $err;
@@ -24,7 +23,7 @@ Evo::Comp::Util
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -32,7 +31,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
