@@ -1,13 +1,16 @@
 package Evo::Default;
 use strict;
 use warnings;
-use feature ();
 
 sub import {
   $_->import for qw(strict warnings utf8);
-  feature::->import(':5.20');
+  feature::->import(':5.22');
+
   feature::->import('postderef');
   warnings::->unimport('experimental::postderef');
+
+  feature::->import('signatures');
+  warnings::->unimport('experimental::signatures');
 }
 
 1;
@@ -24,7 +27,7 @@ Evo::Default
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 DESCRIPTION
 
@@ -41,7 +44,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
