@@ -18,14 +18,10 @@ EXPORTER->add_sub(__PACKAGE__, $_) for @EXPORT;
 
 sub import { export_install_in(scalar caller, @_); }
 
-sub export_install_in {
-  my ($dst, $src, @list) = @_;
-  EXPORTER->install($src, $dst, @list) if @list;
-}
+sub export_install_in($dst, $src, @list) { EXPORTER->install($src, $dst, @list) if @list; }
 
 # pay attention: without provided name all aliases will be found by _find_subnames and exported
-sub MODIFY_CODE_ATTRIBUTES {
-  my ($pkg, $code, @attrs) = @_;
+sub MODIFY_CODE_ATTRIBUTES($pkg, $code, @attrs) {
   my (@bad, @good);
   foreach my $attr (@attrs) {
     my ($attr_name, $val) = _parse_attr($attr);
@@ -41,8 +37,7 @@ sub MODIFY_CODE_ATTRIBUTES {
   return;
 }
 
-sub _parse_attr {
-  my $attr = shift;
+sub _parse_attr($attr) {
   $attr =~ /(\w+) ( \( \s* (\w+) \s* \) )?/x;
   return ($1, $3);
 }
@@ -50,26 +45,22 @@ sub _parse_attr {
 
 sub _add_gen { EXPORTER->add_gen(__PACKAGE__, shift, shift); }
 
-_add_gen export_gen => sub {
-  my $dst = shift;
+_add_gen export_gen => sub($dst) {
   sub { EXPORTER->add_gen($dst, shift, shift) }
 };
 
-_add_gen export_anon => sub {
-  my $dst = shift;
+_add_gen export_anon => sub($dst) {
   sub {
     my ($name, $fn) = @_;
     EXPORTER->add_gen($dst, $name, sub {$fn});
   };
 };
 
-_add_gen export => sub {
-  my $dst = shift;
+_add_gen export => sub($dst) {
   sub { EXPORTER->add_sub($dst, $_) for @_ }
 };
 
-_add_gen export_proxy => sub {
-  my $dst = shift;
+_add_gen export_proxy => sub($dst) {
   sub { EXPORTER->proxy($dst, shift, shift); }
 };
 
@@ -87,7 +78,7 @@ Evo::Export
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 DESCRIPTION
 
@@ -112,37 +103,7 @@ Standart L<Exporter> wasn't good enough for me, so I've written a new one from t
   foo();
   bar();
 
-=head2 RUNNING EXAMPLES
-
-!!!Pay attention. Too keep examples inlined, we use "-Loaded", to mark inline packages as loaded. If you got "Can't load..." or "My::Lib exports nothing" or similar error,  don't forget it.
-
-for example: 
-
-  package main;
-  use Evo;
-
-  {
-
-    package My::Lib;
-    use Evo '-Export *; -Loaded; -Modern';
-
-    BEGIN {
-      export_gen foo => sub ($class) {
-        say "$class requested me";
-        sub {"hello, $class"};
-      };
-    }
-  };
-
-
-  use My::Lib '*';
-  foo();
-
-C<-Loaded> is neccessary for C<use>, and C<BEGIN> for C<export_gen>
-
-In the real code, if you module has it's own file (and perl can read it) you don't need L<Evo::Loaded> or C<BEGIN>
-
-=head2 IMPORTING
+=head1 IMPORTING
 
   use Evo;
   use Evo::Eval 'eval_try';
@@ -152,30 +113,9 @@ For convenient, you can load all above in one line
 
   use Evo '-Eval eval_try; -Promises promise, deferred';
 
-=head3 shortcuts
+C<*> means load all. C<-> is a shortcut. See L<Evo/"shortcuts>
 
-You can you shortcuts: C<-> is replaced by C<Evo>
-
-  # the same, but shorter
-  use Evo '-Promises promise';
-
-And these make sense in the package and depends on the package name where is used
-
-C<:> means relative to the current module as a child
-
-  package My::App;
-  use Evo ':Bar'; # My::App::Bar
-
-C<::> means as sibling (child of the parent of the current module)
-
-  package My::App;
-  use Evo '::Bar'; # My::Bar
-
-C<*> means load all
-
-  use Evo '-Promises *';
-
-=head3 what to import and how
+=head2 what to import and how
 
 You can rename subroutines to avoid method clashing
 
@@ -193,7 +133,7 @@ renamed version of that name
   # import all as is but only deferred will be renamed to "renamed_deferred"
   use Evo '-Promises *, -deferred, deferred:renamed_deferred';
 
-=head2 EXPORTING
+=head1 EXPORTING
 
 Using attribute C<Export>
 
@@ -203,7 +143,7 @@ Using attribute C<Export>
   {
 
     package My::Lib;
-    use Evo -Loaded;
+    use Evo -Loaded; # don't needed in the real code
     use Evo '-Export *';
 
     sub foo : Export {say 'foo'}
@@ -220,10 +160,6 @@ You can export with another name
   # export as bar
   sub foo : Export(bar) {say 'foo'}
 
-=head3 Features
-
-Pay attention, to explore all feature, you need store packages in the real separate file, C<-Loaded> won't always work. (or wrap them in BEGIN blocks)
-
 =head4 export 'foo';
 
 C<Export> signature is more preffered way, but if you wish
@@ -264,21 +200,19 @@ Export function, that won't be available in the source class
 
     # BEGIN and Loaded only for copy-paste example
     package My::Lib;
-    use Evo '-Export *; -Loaded; -Modern';
+    use Evo '-Export *; -Loaded';
 
-    BEGIN {
-      export_gen foo => sub ($class) {
-        say "$class requested me";
-        sub {"hello, $class"};
-      };
-    }
+    export_gen foo => sub ($class) {
+      say "$class requested me";
+      sub {"hello, $class"};
+    };
   };
 
 
-  use My::Lib '*';
+  My::Lib->import('*');
   foo();
 
-Very powefull and most excited feature. C<Evo::Export> export generators, that produces subroutines. Consider it as a 3nd dimension in 3d programming
+Very powefull and most exciting feature. C<Evo::Export> exports generators, that produces subroutines. Consider it as a 3nd dimension in 3d programming
 
 Implementation garanties that one module will get the same (cashed) generated unit (if it'l import twice or import from module that reimport the same thing), but different module will get another one
 
@@ -300,7 +234,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
