@@ -11,8 +11,7 @@ sub new { bless {data => {}}, __PACKAGE__ }
 
 sub data { shift->{data} }
 
-sub install {
-  my ($self, $src, $dst, @xlist) = @_;
+sub install($self, $src, $dst, @xlist) {
   my @list = $self->expand_wildcards($src, @xlist);
 
   my %patch;
@@ -26,8 +25,7 @@ sub install {
   Evo::Util::monkey_patch $dst, %patch;
 }
 
-sub request_gen {
-  my ($self, $epkg, $name, $dpkg) = @_;
+sub request_gen($self, $epkg, $name, $dpkg) {
   my $slot = $self->find_slot($epkg, $name);
 
   # it's important to return same function for the same module
@@ -36,31 +34,25 @@ sub request_gen {
 }
 
 # traverse to find gen via links, return Module, name, gen
-sub find_slot {
-  my ($self, $pkg, $name) = @_;
+sub find_slot($self, $pkg, $name) {
   croak qq{"$pkg" doesn't export "$name"} unless my $slot = $self->data->{$pkg}{$name};
 }
 
-sub init_slot {
-  my ($self, $src, $name, $val) = @_;
+sub init_slot($self, $src, $name, $val) {
   croak "$src already exports $name" if $self->data->{$src}{$name};
   $self->data->{$src}{$name} = $val;
 }
 
-sub add_proxy {
-  my ($self, $epkg, $ename, $spkg, $sname) = @_;
+sub add_proxy($self, $epkg, $ename, $spkg, $sname) {
   my $slot = $self->find_slot($spkg, $sname);
-
   $self->init_slot($epkg, $ename, $slot);
 }
 
-sub add_gen {
-  my ($self, $src, $name, $gen) = @_;
+sub add_gen($self, $src, $name, $gen) {
   $self->init_slot($src, $name, {gen => $gen});
 }
 
-sub add_sub {
-  my ($self, $src, $name_as) = @_;
+sub add_sub($self, $src, $name_as) {
   my ($name, $as) = split ':', $name_as;
   $as ||= $name;
   my $full = "${src}::$name";
@@ -69,8 +61,7 @@ sub add_sub {
   $self->add_gen($src, $as, sub {$sub});
 }
 
-sub proxy {
-  my ($self, $epkg, $spkg, @xlist) = @_;
+sub proxy($self, $epkg, $spkg, @xlist) {
   $spkg = Evo::Util::resolve_package(scalar caller, $spkg);
   load $spkg;
   my @list = $self->expand_wildcards($spkg, @xlist);
@@ -83,8 +74,7 @@ sub proxy {
 
 }
 
-sub expand_wildcards {
-  my ($self, $src, @list) = @_;
+sub expand_wildcards($self, $src, @list) {
   croak "Empty list" unless @list;
 
   my $data = $self->data->{$src};
@@ -119,7 +109,7 @@ Evo::Export::Exporter
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -127,7 +117,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
