@@ -1,6 +1,6 @@
 package Evo::Lib;
-use Evo '-Export *', -Util, 'Carp croak';
-use Time::HiRes qw(CLOCK_MONOTONIC clock_gettime);
+use Evo '-Export *', -Util;
+use Time::HiRes qw(CLOCK_MONOTONIC);
 
 PATCH: {
   no warnings 'once';
@@ -8,21 +8,15 @@ PATCH: {
   *Evo::Lib::monkey_patch = *Evo::Util::monkey_patch{CODE};
 }
 
-export qw(debug context_result monkey_patch);
+export qw(debug monkey_patch);
 
-my $HAS_M_TIME = eval { clock_gettime(CLOCK_MONOTONIC); 1 };
+
+my $HAS_M_TIME = eval { Time::HiRes::clock_gettime(CLOCK_MONOTONIC); 1; };
 
 export_anon steady_time => $HAS_M_TIME
-  ? sub { clock_gettime(CLOCK_MONOTONIC); }
+  ? sub { Time::HiRes::clock_gettime(CLOCK_MONOTONIC); }
   : \&Time::HiRes::time;
 
-sub context_result($) {
-  return unless $_[0];
-  return if !defined $_[0][0];
-  $_[0][0] ? (@{$_[0][1]}) : $_[0][1];
-}
-
-
 sub ws_combine : Export {
   return unless @_;
   return $_[0] if @_ == 1;
@@ -48,7 +42,7 @@ Evo::Lib
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -56,7 +50,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
