@@ -1,8 +1,7 @@
 package Evo::Loop::Comp;
-use Evo '-Comp *', '-Lib steady_time', '-Export *';
+use Evo '-Comp *', '-Lib steady_time', '-Export *; -Realm *';
 use List::Util 'first';
 use Time::HiRes 'usleep';
-use Carp 'croak';
 
 has is_running => 0;
 has tick_time => \&steady_time, is => 'rw';
@@ -10,11 +9,10 @@ has tick_time => \&steady_time, is => 'rw';
 with 'Evo::Loop::Role::Zone', 'Evo::Loop::Role::Timer', 'Evo::Loop::Role::Handle',
   'Evo::Loop::Role::Postpone';
 
-sub update_tick_time { $_[0]->tick_time(steady_time()); }
+sub update_tick_time { shift->tick_time(steady_time()); }
 
 # return number of event, or 0 if no events left and we can stop
-sub tick {
-  my $self = shift;
+sub tick($self) {
   $self->update_tick_time();
 
   my $handle_count   = $self->handle_count;
@@ -30,8 +28,7 @@ sub tick {
 }
 
 # sleep in usleep or in handle_process. Assumming there is at least some event
-sub maybe_sleep {
-  my $self = shift;
+sub maybe_sleep($self) {
   $self->update_tick_time;
   my ($tc, $sc) = ($self->timer_count(), $self->handle_count());
 
@@ -45,7 +42,7 @@ sub maybe_sleep {
 }
 
 
-sub start { $_[0]->maybe_sleep while $_[0]->tick; }
+sub start($self) { $self->maybe_sleep while $self->tick; }
 
 1;
 
@@ -61,7 +58,7 @@ Evo::Loop::Comp
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -69,7 +66,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
