@@ -26,17 +26,18 @@ sub _mask_fd {
   return ($mask, $fd);
 }
 
-sub handle_catch : Role {
-  my ($self, $handle, $fn) = @_;
+sub handle_error($self, $handle, $fn) : Role {
   my $slot = $self->handle_data->{fileno($handle)}
-    or croak "Install events for $handle before catch";
-  croak "$handle already has catch" if exists $slot->{catch};
+    or croak "Install events for $handle before error";
+  croak "$handle already has error" if exists $slot->{error};
 
-  $slot->{catch} = $self->zone_cb($fn);
+  $slot->{error} = $self->zone_cb($fn);
 }
 
-sub handle : Role {
-  my ($self, $handle, $type, $fn) = @_;
+sub handle_in : Role  { handle('in',  @_) }
+sub handle_out : Role { handle('out', @_) }
+
+sub handle($type, $self, $handle, $fn) {
   my ($mask, $fd) = _mask_fd($self, $handle, $type);
   my $data = $self->handle_data;
   croak qq#$handle already has "$type"# if $data->{$fd}{$type};
@@ -44,8 +45,10 @@ sub handle : Role {
   $data->{$fd}{mask} |= $mask;
 }
 
-sub handle_remove : Role {
-  my ($self, $handle, $type, $fn) = @_;
+sub handle_remove_in : Role  { handle_remove(in  => @_) }
+sub handle_remove_out : Role { handle_remove(out => @_) }
+
+sub handle_remove($type, $self, $handle) {
   my ($mask, $fd) = _mask_fd($self, $handle, $type);
   my $data = $self->handle_data;
   croak qq#$handle hasn't "$type"# unless exists $data->{$fd}{$type};
@@ -57,13 +60,11 @@ sub handle_remove : Role {
   else { delete $data->{$fd}; }
 }
 
-sub handle_remove_all : Role {
-  my ($self, $handle) = @_;
+sub handle_remove_all($self, $handle) : Role {
   delete $self->handle_data->{fileno $handle};
 }
 
-sub handle_process : Role {
-  my ($self, $timeout_float) = @_;
+sub handle_process($self, $timeout_float=undef) : Role {
   my $data = $self->handle_data;
   return unless keys $data->%*;
   my $timeout_ms = $timeout_float ? int($timeout_float * 1000) : 0;
@@ -74,7 +75,7 @@ sub handle_process : Role {
       my $slot = $data->{$fd};
       $slot->{in}->()    if $revents & SOCKET_IN;
       $slot->{out}->()   if $revents & SOCKET_OUT;
-      $slot->{catch}->() if ($revents & SOCKET_ERR) && $slot->{catch};
+      $slot->{error}->() if ($revents & SOCKET_ERR) && $slot->{error};
     }
   }
 }
@@ -93,7 +94,7 @@ Evo::Loop::Role::Handle
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -101,7 +102,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
