@@ -5,11 +5,11 @@ requires qw(zone_cb);
 
 has data_postpone => default => sub { [] };
 
-sub postpone_count : Role { $_[0]->data_postpone->@* }
-sub postpone : Role { push $_[0]->data_postpone->@*, $_[0]->zone_cb($_[1]); }
+sub postpone_count($self) : Role { $self->data_postpone->@* }
+sub postpone($self, $fn) : Role { push $self->data_postpone->@*, $self->zone_cb($fn); }
 
-sub postpone_process : Role {
-  my $postpone = $_[0]->data_postpone;
+sub postpone_process($self) : Role {
+  my $postpone = $self->data_postpone;
   shift(@$postpone)->() while @$postpone;
 }
 
@@ -27,7 +27,7 @@ Evo::Loop::Role::Postpone
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -35,7 +35,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
