@@ -12,24 +12,21 @@ has timer_queue => sub { [] };
 
 sub timer_count : Role { scalar $_[0]->timer_queue->@* }
 
-sub timer : Role {
-  my ($self, $after) = (shift, shift);
-  my $zcb = $self->zone_cb(shift);
+sub timer($self, $after, $cb) : Role {
+  my $zcb = $self->zone_cb($cb);
 
   push $self->timer_need_sort(1)->timer_queue->@*, my $slot = [$self->tick_time + $after, $zcb];
   $slot;
 }
 
-sub timer_remove : Role {
-  my ($self, $ref) = @_;
+sub timer_remove($self, $ref) : Role {
   my $que = $self->timer_queue;
 
   defined(my $index = first { $que->[$_] == $ref } 0 .. $#$que) or return;
   splice $que->@*, $index, 1;
 }
 
-sub timer_sort_if_needed : Role {
-  my $self = shift;
+sub timer_sort_if_needed($self) : Role {
   return unless $self->timer_need_sort;
   my $timer_queue = $self->timer_queue;
   $timer_queue->@* = sort { $a->[0] <=> $b->[0] } $timer_queue->@*;
@@ -39,8 +36,7 @@ sub timer_sort_if_needed : Role {
 # queue is a list of unsorted timers. Queue becomes sorted at the beginning.
 # Adding timer makes queue unsorted again.
 # because timers are sorted, process till first future timer
-sub timer_process : Role {
-  my $self = shift;
+sub timer_process($self) : Role {
   $self->timer_sort_if_needed();
   my $time        = $self->tick_time;
   my $timer_queue = $self->timer_queue;
@@ -51,8 +47,7 @@ sub timer_process : Role {
 # calculates a timeout the app can sleep without missing timer
 # assumes that have at least one timer. Calls sort_if_needed
 # returns ms (1s/1000), >=0
-sub timer_calculate_timeout : Role {
-  my $self = shift;
+sub timer_calculate_timeout($self) : Role {
   $self->timer_sort_if_needed();
   my $timeout = ($self->timer_queue->[0][0] - $self->tick_time);
   return $timeout > 0 ? $timeout : 0;
@@ -72,7 +67,7 @@ Evo::Loop::Role::Timer
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -80,7 +75,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
