@@ -13,8 +13,7 @@ sub zone : Role {
   $fn->();
 }
 
-sub zone_cb : Role {
-  my ($self, $cb) = @_;
+sub zone_cb($self, $cb) : Role {
   my $data = $self->zone_data;
   my $w    = $data->{w};
 
@@ -44,7 +43,7 @@ Evo::Loop::Role::Zone
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -52,7 +51,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
