@@ -2,9 +2,9 @@ package Evo::Promises;
 use Evo;
 use Evo '-Export *; :Deferred; :Promise';
 
-sub promise : Export {
+sub promise($fn) : Export {
   my $d = Evo::Promises::Deferred::new(promise => my $p = Evo::Promises::Promise::new());
-  shift->(sub { $d->resolve(@_) }, sub { $d->reject(@_) });
+  $fn->(sub { $d->resolve(@_) }, sub { $d->reject(@_) });
   $p;
 }
 
@@ -25,7 +25,7 @@ Evo::Promises
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -33,7 +33,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
