@@ -4,16 +4,14 @@ use Evo '-Comp *';
 has 'promise', required => 1, is => 'ro';
 has 'called';
 
-sub reject {
-  my ($self, $r) = @_;
+sub reject($self, $r) {
   return if $self->called;
   $self->called(1)->promise->d_reject_continue($r);
 }
 
-sub resolve {
-  my ($self, $r) = @_;
+sub resolve($self, $v) {
   return if $self->called;
-  $self->called(1)->promise->d_resolve_continue($r);
+  $self->called(1)->promise->d_resolve_continue($v);
 }
 
 1;
@@ -30,7 +28,7 @@ Evo::Promises::Deferred
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -38,7 +36,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
