@@ -11,14 +11,12 @@ has 'state' => PENDING;
 
 #sub assert { shift or croak join '; ', caller() }
 
-sub value : Role {
-  my $self = shift;
+sub value($self) : Role {
   croak "$self isn't fulfilled" unless $self->state eq FULFILLED;
   $self->d_v;
 }
 
-sub reason : Role {
-  my $self = shift;
+sub reason($self) : Role {
   croak "$self isn't rejected" unless $self->state eq REJECTED;
   $self->d_v;
 }
@@ -38,23 +36,20 @@ role_gen then => sub {
   };
 };
 
-sub d_lock_in : Role {
-  my ($self, $parent) = @_;
+sub d_lock_in ($self, $parent) : Role {
 
   #assert(!$self->d_locked);
   #assert(!$self->d_settled);
   unshift $parent->d_children->@*, $self->d_locked(1);
 }
 
-sub d_fulfill : Role {
-  my ($self, $v) = @_;
+sub d_fulfill($self, $v) : Role {
 
   #assert(!$self->d_settled);
   $self->d_settled(1)->state(FULFILLED)->d_v($v);
 }
 
-sub d_reject : Role {
-  my ($self, $r) = @_;
+sub d_reject($self, $r) : Role {
 
   #assert(!$_[0]->d_settled);
   $self->d_settled(1)->state(REJECTED)->d_v($r);
@@ -63,8 +58,7 @@ sub d_reject : Role {
 # 2.3 The Promise Resolution Procedure
 # 2.3.3.2, 2.3.3.4 doesn't make sense in perl (in real world)
 # Changed term obj or func to blessed obj and can "then"
-sub d_resolve : Role {
-  my ($self, $x) = @_;
+sub d_resolve($self, $x) : Role {
 
   #assert(!$self->d_settled);
 
@@ -98,14 +92,12 @@ sub d_resolve : Role {
 }
 
 # reject promise and call traverse with the stack of children
-sub d_reject_continue : Role {
-  my ($self, $reason) = @_;
+sub d_reject_continue($self, $reason) : Role {
   $self->d_reject($reason);
   $self->d_traverse;
 }
 
-sub d_resolve_continue : Role {
-  my ($self, $v) = @_;
+sub d_resolve_continue($self, $v) : Role {
   $self->d_resolve($v);
   return unless $self->d_settled;
   $self->d_traverse;
@@ -117,8 +109,8 @@ role_gen d_traverse => sub {
 
   #assert($postpone);
 
-  sub {
-    my @stack = ($_[0]);
+  sub($self) {
+    my @stack = ($self);
     while (@stack) {
 
       my $parent = shift @stack;
@@ -165,7 +157,7 @@ Evo::Promises::Promise::Driver
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -173,7 +165,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
