@@ -4,24 +4,21 @@ use Evo '-Comp *';
 has 'promise', required => 1, is => 'ro';
 has $_ for qw(called v blocking should_resolve);
 
-sub reject {
-  my ($self, $r) = @_;
+sub reject($self, $r) {
   return if $self->called;
   $self->called(1);
   $self->blocking ? $self->promise->d_reject($r) : $self->promise->d_reject_continue($r);
   $self;
 }
 
-sub resolve {
-  my ($self, $v) = @_;
+sub resolve($self, $v) {
   return if $self->called;
   $self->called(1);
   $self->blocking ? $self->should_resolve(1)->v($v) : $self->promise->d_resolve_continue($v);
   $self;
 }
 
-sub try_thenable {
-  my ($self, $thenable) = @_;
+sub try_thenable($self, $thenable) {
   $self->blocking(1);
 
   # reject drain second time, so don't bother checking "called"
@@ -44,7 +41,7 @@ Evo::Promises::Sync
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head2 SYNOPSIS
 This class exists for internal purposes only to make C<d_resolve> a little bit
@@ -67,7 +64,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
