@@ -7,23 +7,20 @@ use constant {PENDING => 'PENDING', REJECTED => 'REJECTED', FULFILLED => 'FULFIL
 
 export qw(PENDING REJECTED FULFILLED);
 
-sub is_locked_in : Export {
+sub is_locked_in($parent, $child) : Export {
   croak unless defined wantarray;
-  my ($parent, $child) = @_;
   first { $_ == $child } $parent->d_children->@*;
 }
 
-sub is_fulfilled_with : Export {
+sub is_fulfilled_with($v, $p) : Export {
   croak unless defined wantarray;
-  my ($v, $p) = @_;
   return unless $p->d_settled && $p->{state} eq FULFILLED;
   my $dv = $p->d_v;
   return defined $dv ? $v eq $dv : !defined $dv;
 }
 
-sub is_rejected_with : Export {
+sub is_rejected_with($v, $p) : Export {
   croak unless defined wantarray;
-  my ($v, $p) = @_;
   return unless $p->d_settled && $p->{state} eq REJECTED;
   my $dv = $p->d_v;
   return defined $dv ? $v eq $dv : !defined $dv;
@@ -44,7 +41,7 @@ Evo::Promises::Util
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -52,7 +49,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
