@@ -3,10 +3,8 @@ use Carp 'croak';
 use Evo '-Eval *', '-Export *';
 
 
-sub w_eval_run : Export {
-  my $catch = shift or croak "Pass catch function";
-  sub {
-    my $next = shift;
+sub w_eval_run($catch) : Export {
+  sub($next) {
     sub {
       my $call = eval_want(wantarray, @_, $next);
       return $call->result if $call;
@@ -30,7 +28,7 @@ Evo::W::Eval
 
 =head1 VERSION
 
-version 0.0173
+version 0.0184
 
 =head1 AUTHOR
 
@@ -38,7 +36,7 @@ alexbyk.com
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by alexbyk.
+This software is copyright (c) 2016 by alexbyk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
